import json
import os
import time

import requests
from notetool.tool.secret import read_secret


class HuoBiMessage:
    def __init__(self, name='huobi', webhook=None, agent_id=None, secret=None, company_id=None):
        self.name = name
        # 机器人webhook
        self.webhook = read_secret("wechat", "notechats", "huobi", name, "webhook", value=webhook)
        # 应用ID
        self.agent_id = read_secret("wechat", "notechats", "huobi", name, "agent_id", value=agent_id)
        # 应用Secret
        self.secret = read_secret("wechat", "notechats", "huobi", name, "secret", value=secret)
        # 企业ID
        self.company_id = read_secret("wechat", "notechats", "huobi", name, "company_id", value=company_id)

    def send_msg(self, msg):
        self.send_to_wechat(msg)
        self.send_to_qywx(msg)

    def send_to_qywx(self, msg):
        headers = {'Content-Type': 'application/json'}
        data = {
            "msgtype": "text",
            "text": {
                "content": msg
            }
        }

        data = json.dumps(data)
        r = requests.post(url=self.webhook, headers=headers, data=data)

    def send_to_wechat(self, message):
        """
        :param agent_id: 应用ID
        :param secret: 应用Secret
        :param company_id: 企业ID
        :param message:
        """
        # 通行密钥
        access_token = None
        # 如果本地保存的有通行密钥且时间不超过两小时，就用本地的通行密钥
        if os.path.exists('ACCESS_TOKEN.txt'):
            txt_last_edit_time = os.stat('ACCESS_TOKEN.txt').st_mtime
            now_time = time.time()
            print('ACCESS_TOKEN_time:', int(now_time - txt_last_edit_time))
            if now_time - txt_last_edit_time < 3600:  # 官方说通行密钥2小时刷新
                with open('ACCESS_TOKEN.txt', 'r') as f:
                    access_token = f.read()
                    # print(ACCESS_TOKEN)
        # 如果不存在本地通行密钥，通过企业ID和应用Secret获取
        if not access_token:
            r = requests.post(
                f'https://qyapi.weixin.qq.com/cgi-bin/gettoken?corpid={self.company_id}&corpsecret={self.secret}').json()

            access_token = r["access_token"]
            # print(ACCESS_TOKEN)
            # 保存通行密钥到本地ACCESS_TOKEN.txt
            with open('ACCESS_TOKEN.txt', 'w', encoding='utf-8') as f:
                f.write(access_token)
        # 要发送的信息格式
        data = {
            "touser": "@all",
            "msgtype": "text",
            "agentid": f"{self.agent_id}",
            "text": {"content": f"{message}"}
        }
        # 字典转成json，不然会报错
        data = json.dumps(data)
        # 发送消息
        r = requests.post(f'https://qyapi.weixin.qq.com/cgi-bin/message/send?access_token={access_token}', data=data)


huobi = HuoBiMessage()
huobi.send_msg("success")



import json
import os
import time

import requests
from notetool.tool.secret import read_secret
from wechatpy.enterprise import WeChatClient


class HuoBiMessage:
    def __init__(self, name='huobi', webhook=None, agent_id=None, secret=None, company_id=None):
        self.name = name
        # 机器人webhook
        self.webhook = read_secret("wechat", "notechats", "huobi", name, "webhook", value=webhook)
        # 应用ID
        self.agent_id = read_secret("wechat", "notechats", "huobi", name, "agent_id", value=agent_id)
        # 企业ID
        self.company_id = read_secret("wechat", "notechats", "huobi", name, "company_id", value=company_id)
        # 应用Secret
        self.secret = read_secret("wechat", "notechats", "huobi", name, "secret", value=secret)
        self.client = WeChatClient(corp_id=self.company_id, secret=self.secret)

    def send_msg(self, msg):
        self.check_token()
        data = {
            "msgtype": "text",
            "text": {
                "content": msg
            }
        }
        self.client.message.send(agent_id=self.agent_id, user_ids=['NiuLiangTao', 'GuoYe'], party_ids=['3'], msg=data)

        self.send_to_qywx(msg)

    def send_to_qywx(self, msg):
        headers = {'Content-Type': 'application/json'}
        data = {
            "msgtype": "text",
            "text": {
                "content": msg
            }
        }

        data = json.dumps(data)
        r = requests.post(url=self.webhook, headers=headers, data=data)

    def check_token(self):
        # 通行密钥
        access_token = None
        # 如果本地保存的有通行密钥且时间不超过两小时，就用本地的通行密钥
        if os.path.exists('ACCESS_TOKEN.txt'):
            txt_last_edit_time = os.stat('ACCESS_TOKEN.txt').st_mtime
            now_time = time.time()
            #print('ACCESS_TOKEN_time:', int(now_time - txt_last_edit_time))
            if now_time - txt_last_edit_time < 3600:  # 官方说通行密钥2小时刷新
                with open('ACCESS_TOKEN.txt', 'r') as f:
                    access_token = f.read()
        # 如果不存在本地通行密钥，通过企业ID和应用Secret获取
        if not access_token:
            r = requests.post(
                f'https://qyapi.weixin.qq.com/cgi-bin/gettoken?corpid={self.company_id}&corpsecret={self.secret}').json()

            access_token = r["access_token"]
            # 保存通行密钥到本地ACCESS_TOKEN.txt
            with open('ACCESS_TOKEN.txt', 'w', encoding='utf-8') as f:
                f.write(access_token)
        self.client.session.set(self.client.access_token_key, access_token)
        return access_token



import json
import os
import time
from time import sleep

import requests
from notecoin.huobi.client import GenericClient
from notecoin.huobi.strategy.message import HuoBiMessage
from notetool.tool.log import logger
from notetool.tool.secret import read_secret


class FindNewCoin:
    def __init__(self):
        self.huobi = HuoBiMessage()

        api_key = read_secret(cate1='coin', cate2='huobi', cate3='api_key')
        secret_key = read_secret(cate1='coin', cate2='huobi', cate3='secret_key')

        self.generic = GenericClient(api_key=api_key, secret_key=secret_key)
        self.symbol_df_last = None
        self.symbol_df_now = None
        self.symbol_dict = {}

    def init(self):
        df = self.generic.get_exchange_symbols().data
        self.symbol_df_last = self.symbol_df_now = df
        symbols = df[['symbol', 'state']].values
        for symbol, status in symbols:
            self.symbol_dict[symbol] = status
            if 'lat' in symbol:
                print(symbol)

    def update(self, df):
        self.symbol_df_last = self.symbol_df_now
        self.symbol_df_now = df

        symbols = df[['symbol', 'state']].values
        for symbol, status in symbols:
            if symbol not in self.symbol_dict.keys():
                self.huobi.send_msg(f"new symbol:{symbol}:{status}")
                self.symbol_dict[symbol] = status
            elif status != self.symbol_dict[symbol]:
                self.huobi.send_msg(f"status change:{symbol}:{self.symbol_dict[symbol]}->{status}")
                self.symbol_dict[symbol] = status
            else:
                pass

    def run(self):
        self.init()
        step = 0
        while True:
            try:
                df = self.generic.get_exchange_symbols().data
                self.update(df)
            except Exception as e:
                print(e)
                logger.info(f"error:{e}")

            if step % 8640 == 0:
                self.info()

            sleep(10)
            step += 1

    def info(self):
        status_dict = {}
        for k, v in self.symbol_dict.items():
            ks = status_dict.get(v, [])
            ks.append(k)
            status_dict[v] = ks

        for k, v in status_dict.items():
            self.huobi.send_msg(f"{k}:\t{', '.join(v)}")


find = FindNewCoin()
find.run()


# ps -elf|grep check_new
# nohup /root/anaconda3/bin/python3.8 /root/workspace/notechats/notecoin/notecoin/huobi/strategy/check_new.py >>/root/workspace/tmp/notecoin-check-run-$(date +%Y-%m-%d).log 2>&1 &



def etf_result_check(code):
    code = int(code)
    if code == 200:
        return ""
    elif code == 10400:
        return "Invalid ETF name"
    elif code == 13403:
        return "Insufficient asset to create ETF"
    elif code == 13404:
        return "Create and redemption disabled due to system setup"
    elif code == 13405:
        return "Create and redemption disabled due to configuration issue"
    elif code == 13406:
        return "Invalid API call"
    elif code == 13410:
        return "API authentication fails"
    elif code == 13500:
        return "System error"
    elif code == 13601:
        return "Create and redemption disabled during rebalance"
    elif code == 13603:
        return "Create and redemption disabled due to other reason"
    elif code == 13604:
        return "Create suspended"
    elif code == 13605:
        return "Redemption suspended"
    elif code == 13606:
        return "Amount incorrect. For the cases when creation amount or redemption amount is not in the range of min/max amount"
    return ""
